#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

install_requires = \
['numpy >=1.17.4']

setup(name='trieres',
      version='0.2',
      description='A package for cloudFPGA quantitative finance lib.',
      author='Dionysios Diamantopoulos',
      author_email='did@zurich.ibm.com',
      url='https://github.com/cloudFPGA/trieres',
      py_modules=['trieres'],
      install_requires=install_requires,
      python_requires='>=3.7',
     )
